Module results

Module results 

Error and Result types

This module contains definitions for the main Result types used throughout the parser.

Structs

ParserError
The general error structure

Enums

ParserErrorDetails
A global enumeration of error codes
ParserErrorSource
Enumeration of the various different parser stages that can produce an error

Type Aliases

ParserResult
Global result type used throughout the parser stages